@@ -69,6 +69,7 @@ from gpt_index.readers import (
     FaissReader,
     GithubRepositoryReader,
     GoogleDocsReader,
+    JSONReader,
     MboxReader,
     NotionPageReader,
     ObsidianReader,
@@ -125,6 +126,7 @@ __all__ = [
     "ObsidianReader",
     "Document",
     "SimpleDirectoryReader",
+    "JSONReader",
     "SimpleMongoReader",
     "NotionPageReader",
     "GoogleDocsReader",
