@@ -21,6 +21,7 @@ from gpt_index.readers.github_readers.github_repository_reader import (
     GithubRepositoryReader,
 )
 from gpt_index.readers.google_readers.gdocs import GoogleDocsReader
+from gpt_index.readers.json import JSONReader
 from gpt_index.readers.make_com.wrapper import MakeWrapper
 from gpt_index.readers.mbox import MboxReader
 from gpt_index.readers.mongo import SimpleMongoReader
@@ -46,6 +47,7 @@ __all__ = [
     "WikipediaReader",
     "YoutubeTranscriptReader",
     "SimpleDirectoryReader",
+    "JSONReader",
     "SimpleMongoReader",
     "NotionPageReader",
     "GoogleDocsReader",
